==> RsCMPX_Gprf-4.0.172.tar.gz: RsCMPX_Gprf-4.0.172/RsCMPX_Gprf/Implementations/Catalog/Gprf/Generator/Spath/Group.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GroupCls:
	"""Group commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	def get_connector(self) -> str:
		"""SCPI: CATalog:GPRF:GENerator<Instance>:SPATh:GROup:CONNector \n
		Snippet: value: str = driver.catalog.gprf.generator.spath.group.get_connector() \n
		Returns the names of the connectors of the active connector group. Select the connector group via method RsCMPX_Gprf.
		Route.Gprf.Generator.Spath.value. \n
			:return: connector_name: Comma-separated list of values, one value per connector.
		"""
		response = self._core.io.query_str('CATalog:GPRF:GENerator<Instance>:SPATh:GROup:CONNector?')
		return trim_str_response(response)

	def get(self, connector_name: str) -> List[str]:
		"""SCPI: CATalog:GPRF:GENerator<Instance>:SPATh:GROup \n
		Snippet: value: List[str] = driver.catalog.gprf.generator.spath.group.get(connector_name = '1') \n
		Returns the names of the signal paths that start at the specified connector. This command is only relevant if you create
		your own signal paths (see base manual) . The default signal paths have the same name as the assigned connector. \n
			:param connector_name: Start point of the signal paths.
			:return: signal_path: Comma-separated list of strings, one string per signal path."""
		param = Conversions.value_to_quoted_str(connector_name)
		response = self._core.io.query_str(f'CATalog:GPRF:GENerator<Instance>:SPATh:GROup? {param}')
		return Conversions.str_to_str_list(response)

==> RsCMPX_Gprf-5.0.20.tar.gz: RsCMPX_Gprf-5.0.20/RsCMPX_Gprf/Implementations/Catalog/Gprf/Generator/Spath/Group.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GroupCls:
	"""Group commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	def get_connector(self) -> str:
		"""SCPI: CATalog:GPRF:GENerator<Instance>:SPATh:GROup:CONNector \n
		Snippet: value: str = driver.catalog.gprf.generator.spath.group.get_connector() \n
		Returns the names of the connectors of the active connector group. Select the connector group via method RsCMPX_Gprf.
		Route.Gprf.Generator.Spath.value. \n
			:return: connector_name: Comma-separated list of values, one value per connector.
		"""
		response = self._core.io.query_str('CATalog:GPRF:GENerator<Instance>:SPATh:GROup:CONNector?')
		return trim_str_response(response)

	def get(self, connector_name: str) -> List[str]:
		"""SCPI: CATalog:GPRF:GENerator<Instance>:SPATh:GROup \n
		Snippet: value: List[str] = driver.catalog.gprf.generator.spath.group.get(connector_name = 'abc') \n
		Returns the names of the signal paths that start at the specified connector. This command is only relevant if you create
		your own signal paths (see base manual) . The default signal paths have the same name as the assigned connector. \n
			:param connector_name: Start point of the signal paths.
			:return: signal_path: Comma-separated list of strings, one string per signal path."""
		param = Conversions.value_to_quoted_str(connector_name)
		response = self._core.io.query_str(f'CATalog:GPRF:GENerator<Instance>:SPATh:GROup? {param}')
		return Conversions.str_to_str_list(response)
